/**
 * Default components for PraisonAIUI
 */

export { Header, type HeaderProps } from "./slots/Header";
export { Footer, type FooterProps } from "./slots/Footer";
export { DocsSidebar, type DocsSidebarProps } from "./slots/DocsSidebar";
export { Toc, type TocProps } from "./slots/Toc";
export { DocContent, type DocContentProps } from "./slots/DocContent";

export { ThreeColumnLayout, type ThreeColumnLayoutProps } from "./layouts/ThreeColumnLayout";
export { DefaultLayout, type DefaultLayoutProps } from "./layouts/DefaultLayout";
